==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/NoSlots.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoSlots:
	"""NoSlots commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("noSlots", core, parent)

	def set(self, no_slots: enums.NfcNumOfSlots, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:NOSLots \n
		Determines the number of slots. \n
			:param no_slots: S1| S2| S4| S8| S16
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(no_slots, enums.NfcNumOfSlots)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:NOSLots {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcNumOfSlots:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:NOSLots \n
		Determines the number of slots. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: no_slots: S1| S2| S4| S8| S16"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:NOSLots?')
		return Conversions.str_to_scalar_enum(response, enums.NfcNumOfSlots)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/NoSlots.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoSlots:
	"""NoSlots commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("noSlots", core, parent)

	def set(self, no_slots: enums.NfcNumOfSlots, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:NOSLots \n
		Snippet: driver.source.bb.nfc.cblock.noSlots.set(no_slots = enums.NfcNumOfSlots.S1, channel = repcap.Channel.Default) \n
		Determines the number of slots. \n
			:param no_slots: S1| S2| S4| S8| S16
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(no_slots, enums.NfcNumOfSlots)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:NOSLots {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcNumOfSlots:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:NOSLots \n
		Snippet: value: enums.NfcNumOfSlots = driver.source.bb.nfc.cblock.noSlots.get(channel = repcap.Channel.Default) \n
		Determines the number of slots. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: no_slots: S1| S2| S4| S8| S16"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:NOSLots?')
		return Conversions.str_to_scalar_enum(response, enums.NfcNumOfSlots)
